@@ -1,7 +1,7 @@
 package BenchmarkAnything::Storage::Backend::SQL::Query::common;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: BenchmarkAnything::Storage::Backend::SQL - querying - backend base class
-$BenchmarkAnything::Storage::Backend::SQL::Query::common::VERSION = '0.019';
+$BenchmarkAnything::Storage::Backend::SQL::Query::common::VERSION = '0.020';
 use strict;
 use warnings;
 use base 'BenchmarkAnything::Storage::Backend::SQL::Query';
@@ -46,7 +46,7 @@ sub create_where_clause {
         || $ar_value->[0] eq '<='
         || $ar_value->[0] eq '>='
     ) {
-        $s_where_clause = "$s_column_name $ar_value->[0] (0 + ?)";
+        $s_where_clause = "$s_column_name $ar_value->[0] ?";
     }
     elsif ( $ar_value->[0] eq '=' ) {
         if ( $#{$ar_value} > 1 ) {
